import os, json
from numpy.random import randint

def open_json(json_file):
    with open(json_file) as data:
        return json.load(data)

def write_dotenv(env, file=".env"):
    """
    python-dotenv dont have any function to overwrite .env file
    write_dotenv is just a write variables in text file
    """
    with open(".env", "w") as f:
        for i in env:
            f.write(f'{i}={env[i]}\n')

def to_print_dict(dic:dict,spaces = 4):
    """
    @ make the dict a key: value table string
    """
    ret = ''
    for i in dic:
        ret = ret + f"""{i}: {dic[i]}\n{spaces*' '}"""
    return ret

def print_dict(dic:dict):
    """
    @ just print to_print_dict
    """
    print(to_print_dict(dic))

def sample(vec):
    """Return 1 random value of a vector 
    Args:
        vec :list: list or a pd.Series or pd.Dataframe
    Returns:
        what is inside the list/dataframe/series index []
    """
    return vec[randint(len(vec))]

def to_print_list(ls):
    """just remove [] from list to print it"""
    ret = ''
    for i in ls:
        ret=ret+f'{i},'
    return ret[:-1]

def print_list(ls):
    """print the list without []"""
    print(to_print_list(ls))


import matplotlib.pyplot as plt
import pandas as pd

def two_line_plot(df, x1, x2, freq = 'M', figsize = (20,5), tittle = ''):
    temp = df[['date_time',x1,x2]]
    temp.index = temp.date_time
    temp = temp.resample(freq).mean()
    temp.reset_index(inplace=True)
    plt.figure(figsize = figsize)
    _ = sns.lineplot(x = temp['date_time'],y = temp[x1]).set_title(tittle,fontsize=20)
    _ = sns.lineplot(x = temp['date_time'],y = temp[x2])
    
def two_hist_plot(df, x1, x2, freq = 'M', figsize = figsize2, tittle = ''):
    temp = df[['date_time',x1,x2]]
    temp.index = temp.date_time
    temp = temp.resample(freq).mean()
    temp.reset_index(inplace=True)
    plt.figure(figsize = figsize)
    _ = sns.histplot(df[x1],color = 'red').set_title(tittle,fontsize=20)
    _ = sns.histplot(df[x2]) 

def one_line_plot(df, x1, freq = 'M', figsize = figsize2, tittle = ''):
    temp = df[['date_time',x1]]
    temp.index = temp.date_time
    temp = temp.resample(freq).mean()
    temp.reset_index(inplace=True)
    plt.figure(figsize = figsize)
    _ = sns.lineplot(x = temp['date_time'],y = temp[x1]).set_title(tittle,fontsize=20)

def one_hist_plot(df, x1, freq = 'M', figsize = figsize2, tittle = ''):
    temp = df[['date_time',x1]]
    temp.index = temp.date_time
    temp = temp.resample(freq).mean()
    temp.reset_index(inplace=True)
    plt.figure(figsize = figsize)
    _ = sns.histplot(df[x1],color = 'red').set_title(tittle,fontsize=20)
